#
# Keeps track of the mapping from trans_in.tid to LcgRecords.RecordIdentity 
# This is optional, but recommended.
#
CREATE TABLE MAP_tid_RecordIdentity (
        HLRLocation VARCHAR(255) NOT NULL,
	HLR_tid INT(11) NOT NULL,
	RecordIdentity VARCHAR(255) NOT NULL,
        PRIMARY KEY (HLRLocation, HLR_tid)
);

#
# Conversion log, to keep track of which DGAS tids have been converted
# and when ... important in order to convert each transaction only once.
#
CREATE TABLE ConversionLog (
	ConversionID INT(11) PRIMARY KEY AUTO_INCREMENT,
	ConversionStart DATETIME NOT NULL,
	ConversionEnd DATETIME NOT NULL,
        HLRLocation VARCHAR(255) NOT NULL,
	From_HLR_tid INT(11) NOT NULL,
	To_HLR_tid INT(11) NOT NULL
);

#
# Error handling, in case a record cannot be converted forsees to retry
# a configurable number of times before giving up. The following table
# contains information about which tids to retry, and how many retries
# have already been attempted.
# Only one retry will be attempted per execution of the coversion tool.
#
CREATE TABLE ConversionErrors (
	HLRLocation VARCHAR(255) NOT NULL,
	HLR_tid INT(11) NOT NULL,
	NumRetries INT(11) NOT NULL DEFAULT 0,
	LastTryTimeUTC DATETIME NOT NULL,
	PRIMARY KEY (HLRLocation, HLR_tid)
);

#
# Contains an up-to-date mapping of known ExecutingSites for the
# global CE ID.
# UpdateTimeUTC indicates the time at which the entry was last updated (or
# created).
# ValidityTimeUTC indicates the time at which the validity of the mapping entry
# was last verified.
#
CREATE TABLE MAP_CEID_ExecutingSite (
	CEID VARCHAR(255) PRIMARY KEY NOT NULL,
	ExecutingSite VARCHAR(50) NOT NULL,
	UpdateTimeUTC DATETIME NOT NULL,
	ValidityTimeUTC DATETIME NOT NULL
);

#
# Contains an up-to-date mapping of known benchmarks
# (SpecInt2000 and SpecFloat2000) for the global CE ID.
# UpdateTimeUTC indicates the time at which the entry was last updated (or
# created).
# ValidityTimeUTC indicates the time at which the validity of the mapping entry
# was last verified.
#
CREATE TABLE MAP_CEID_Benchmarks (
	CEID VARCHAR(255) PRIMARY KEY NOT NULL,
	SpecInt2000 INT,
	SpecFloat2000 INT,
	UpdateTimeUTC DATETIME NOT NULL,
	ValidityTimeUTC DATETIME NOT NULL
);

# ...

