#!/usr/bin/perl
#This script queries a VO and creates HLR accounts for
#each person registered in that VO.
#Author: Andrea Guarise, andrea.guarise@to.infn.it
use Net::LDAP;
use Getopt::Std;


getopts('fhp:s:b:v:', \%opts);

if ( $ENV{GLITE_LOCATION} eq "" )
{
        $ENV{GLITE_LOCATION}="/opt/glite/";
}

if ( $opts{f} eq "1" ) { $forceFlag = "-F"; };

if ( $opts{b} eq "" )
{
	$opts{b} = "o=Grid";
}

if ( $opts{v} ne "bdII" )
{
	 $opts{v} = "Mds-Vo-Name";
}

if ( $opts{s} ne "" && $opts{h} ne 1 )
{
	if ( $opts{p} eq "" )
	{
		print "Warning using deafult port: 389\n";
		$opts{p} = 389;
	}
}
else
{
	print "Usage:\n";
	print "dgas_hlr_bdiiImport.pl <OPTIONS>\n";
	print "\nWhere OPTIONS are:\n\n";
	print "-s <hostnmame>  Host name of the BDII server to contact.\n";
	print "-p <port>       Port number for the BDII server to query.\n";
	print "-b <base>       Base string for the query (Default=\"o=Grid\").\n";
	print "-v <voFlag>     Virtual Organisation flag (\"bdII\" or \"Mds-Vo-Name\").\n";
	print "                \"bdII\": Selects the bdII FQDN as the resource's VO ID.\n";
	print "                \"Mds-Vo-Name\": Selects the Mds-Vo-Name record\n";
	print "                                 as the VO ID to which the resource is\n";
	print "                                 associated in the HLR database.\n";
	print "                Default: \"Mds-Vo-Name\".\n";
	print "-f              Force flag, if specified existing accounts are overwritten.\n";
	exit(1);
}


print "$opts{s}\n";
print "$opts{p}\n";
$ldap = Net::LDAP->new($opts{s}, port=>$opts{p});
$msg = $ldap->bind;
$msg = $ldap->search(filter=>"(objectclass=*)", base=>"$opts{b}");
@entries = $msg->entries;

%accounInfo = (
		ceId => "",
		mail => "",
		description => "",
		group => "",
		vo => "",
		rid => ""
	);
$i=0;
foreach $entry (@entries) 
{
        @members = $entry->get_value("GlueCEUniqueID");
	foreach $member (@members)
	{
		my $dn;
		my $ceFQDN;
		my $glueGlueCEName;
		my $ceDomainName;	
		my $suggestedRid;
		$accountInfo{description}=$member;
		$member =~ s/lcgpbs/pbs/g;
		$member =~ s/lcglsf/lsf/g;
		$accountInfo{ceId}=$member;
		$msg2 = $ldap->search(filter=>"(GlueCEUniqueID=$accountInfo{description})", base=>"$opts{b}");
		@entries2 = $msg2->entries;
		foreach $entry2 (@entries2) 
		{
			$dn = $entry2->dn();
			$ceFQDN= $entry2->get_value("GlueCEInfoHostName");
			$glueGlueCEName= $entry2->get_value("GlueCEName");
			$ceDomainName = "";
			if ( $ceFQDN =~ /^(.+?)\.(.*)/)
			{
				$ceDomainName = $2;
			}
			@dnFields = split(',',$dn);
			foreach $dnField (@dnFields )
			{
				if ( $dnField =~ /^Mds-Vo-name=(.*)$/)
				{ 
					$mdsVoName = $1;
				}
			}
		}
		$suggestedRid= $ceFQDN;
		$suggestedRid =~ s/\./_/g;
		$suggestedRid .= "_$glueGlueCEName";
		$accountInfo{group}=$ceDomainName;
		if ( $opts{v} eq "Mds-Vo-Name")
		{
			$accountInfo{vo}=$mdsVoName;
		}
		elsif ( $opts{v} eq "bdII" )
		{
			$accountInfo{vo}=$opts{s};
		}
		$accountInfo{rid}=$suggestedRid;
		$i +=1;
		print "$i\n";
		$aref = \%accountInfo;
		&createAccount($aref);
	}
}


sub createAccount()
{
	my %Info = %{$_[0]};
	my $prefix = "$ENV{GLITE_LOCATION}/sbin/";
	if ( &voExists($Info{vo}) != 0)
	{	
		&createVO(\%Info);
	}
	if ( &groupExists($Info{group}) != 0)
	{
		&createGroup(\%Info);
	}
	my $cmd = "$prefix/glite_dgas_hlrAddResource $forceFlag -r $Info{rid} --vo_id '$Info{vo}' -g '$Info{group}' -d '$Info{description}' -c '$Info{ceId}'";
	print "$cmd\n";
	return system($cmd);
}

sub groupExists
{
	my $group = $_[0];
	my $prefix ="$ENV{GLITE_LOCATION}/sbin/";
	my $cmd = "$prefix/glite_dgas_hlrQueryGroup -g $group";
	my $ret = system($cmd);
	return $ret;
}

sub voExists
{
	my $vo = $_[0];
	my $prefix ="$ENV{GLITE_LOCATION}/sbin/";
	my $cmd = "$prefix/glite_dgas_hlrQueryVO --vo_id $vo";
	my $ret = system($cmd);
	return $ret;
}

sub resourceExists
{
	my $ceID = $_[0];
	my $prefix ="$ENV{GLITE_LOCATION}/sbin/";
	my $cmd = "$prefix/glite_dgas_hlrQueryResource -R -c $ceID";
	my $ret = system($cmd);
	return $ret;
}

sub createGroup()
{
	my %Info = %{$_[0]};
	my $prefix = "$ENV{GLITE_LOCATION}/sbin/";
	my $cmd ="$prefix/glite_dgas_hlrAddGroup $forceFlag --vo_id $Info{vo} -g $Info{group}";	
	print "$cmd\n";
	return system($cmd);
}

sub createVO()
{
	my %Info = %{$_[0]};
	my $prefix = "$ENV{GLITE_LOCATION}/sbin/";
	$voDescription = "ldap://$opts{s}:$opts{p}/$opts{b}";
	my $cmd ="$prefix/glite_dgas_hlAddVO $forceFlag --vo_id $Info{vo}";
	print "$cmd\n";
	$ret = system($cmd);
		
}
